pub struct RequireAuthorizationLayer<T> { /* private fields */ }auth only.Expand description
Layer that applies RequireAuthorization which authorizes all requests using the
Authorization header.
See the module docs for an example.
Implementations
Authorize requests using a username and password pair.
The Authorization header is required to be Basic {credentials} where credentials is
base64_encode("{username}:{password}").
Since the username and password is sent in clear text it is recommended to use HTTPS/TLS with this method. However use of HTTPS/TLS is not enforced by this middleware.
Authorize requests using a custom scheme.