pub enum ServerErrorsFailureClass {
StatusCode(StatusCode),
Error(String),
}Expand description
The failure class for ServerErrorsAsFailures.
Variants
StatusCode(StatusCode)
A response was classified as a failure with the corresponding status.
Error(String)
A response was classified as an error with the corresponding error description.