Struct tower_http::classify::GrpcErrorsAsFailures
source · [−]pub struct GrpcErrorsAsFailures { /* private fields */ }Expand description
Response classifier for gRPC responses.
gRPC doesn’t use normal HTTP statuses for indicating success or failure but instead a special header that might appear in a trailer.
Responses are considered successful if
grpc-statusheader value matchesGrpcErrorsAsFailures::success_codes(onlyOkby default).grpc-statusheader is missing.grpc-statusheader value isn’t a validString.grpc-statusheader value can’t parsed into ani32.
All others are considered failures.
Implementations
Create a new GrpcErrorsAsFailures.
Change which gRPC codes are considered success.
Defaults to only considering Ok as success.
Ok will always be considered a success.
Example
Servers might not want to consider Invalid Argument or Not Found as failures since
thats likely the clients fault:
use tower_http::classify::{GrpcErrorsAsFailures, GrpcCode};
let classifier = GrpcErrorsAsFailures::new()
.with_success(GrpcCode::InvalidArgument)
.with_success(GrpcCode::NotFound);Returns a MakeClassifier that produces GrpcErrorsAsFailures.
This is a convenience function that simply calls SharedClassifier::new.