Struct ServerErrorsAsFailures

struct ServerErrorsAsFailures { ... }

The default classifier used for normal HTTP responses.

Responses with a 5xx status code are considered failures, all others are considered successes.

Implementations

impl ServerErrorsAsFailures

fn new() -> Self

Create a new ServerErrorsAsFailures.

fn make_classifier() -> SharedClassifier<Self>

Returns a MakeClassifier that produces ServerErrorsAsFailures.

This is a convenience function that simply calls SharedClassifier::new.

impl ClassifyResponse for ServerErrorsAsFailures

fn classify_response<B>(self: Self, res: &Response<B>) -> ClassifiedResponse<<Self as >::FailureClass, <Self as >::ClassifyEos>
fn classify_error<E>(self: Self, error: &E) -> <Self as >::FailureClass
where
    E: Display + 'static

impl Clone for ServerErrorsAsFailures

fn clone(self: &Self) -> ServerErrorsAsFailures

impl Debug for ServerErrorsAsFailures

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Default for ServerErrorsAsFailures

fn default() -> ServerErrorsAsFailures

impl Freeze for ServerErrorsAsFailures

impl RefUnwindSafe for ServerErrorsAsFailures

impl Send for ServerErrorsAsFailures

impl Sync for ServerErrorsAsFailures

impl Unpin for ServerErrorsAsFailures

impl UnsafeUnpin for ServerErrorsAsFailures

impl UnwindSafe for ServerErrorsAsFailures

impl<T> Any for ServerErrorsAsFailures

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for ServerErrorsAsFailures

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for ServerErrorsAsFailures

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for ServerErrorsAsFailures

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for ServerErrorsAsFailures

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for ServerErrorsAsFailures

impl<T> PolicyExt for ServerErrorsAsFailures

fn and<P, B, E>(self: Self, other: P) -> And<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>
fn or<P, B, E>(self: Self, other: P) -> Or<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>

impl<T> ToOwned for ServerErrorsAsFailures

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for ServerErrorsAsFailures

impl<T, U> Into for ServerErrorsAsFailures

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for ServerErrorsAsFailures

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for ServerErrorsAsFailures

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>