#[non_exhaustive]pub enum ConfigError {
InvalidOriginUrl {
origin: String,
message: String,
},
InvalidOriginUrlComponents {
origin: String,
},
OpaqueOrigin {
origin: String,
},
NonAsciiHostname {
origin: String,
},
}Available on crate feature
csrf only.Expand description
Errors that can occur while configuring CsrfLayer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidOriginUrl
The origin string could not be parsed as a URI.
InvalidOriginUrlComponents
An origin URL containing a path, query, or fragment was added as a trusted origin.
OpaqueOrigin
An origin with a scheme other than http or https (e.g. file://,
mailto:, or a bare host with no scheme) was added as a trusted
origin. Such origins can never match a browser-supplied request
Origin.
NonAsciiHostname
A trusted origin contained non-ASCII characters. Browsers send IDN
hostnames in punycode form, so the configured value must use the
punycode form (e.g. xn--exmple-cua.com) to ever match.