Struct tower_http::decompression::Decompression
source · [−]pub struct Decompression<S> { /* private fields */ }decompression only.Expand description
Decompresses response bodies of the underlying service.
This adds the Accept-Encoding header to requests and transparently decompresses response
bodies based on the Content-Encoding header.
See the module docs for more details.
Implementations
Consumes self, returning the underlying service.
Returns a new Layer that wraps services with a Decompression middleware.
This is supported on crate feature decompression-gzip only.
decompression-gzip only.Sets whether to request the gzip encoding.
This is supported on crate feature decompression-deflate only.
decompression-deflate only.Sets whether to request the Deflate encoding.
This is supported on crate feature decompression-br only.
decompression-br only.Sets whether to request the Brotli encoding.
Disables the gzip encoding.
This method is available even if the gzip crate feature is disabled.
Disables the Deflate encoding.
This method is available even if the deflate crate feature is disabled.