Enum LatencyUnit

enum LatencyUnit

The latency unit used to report latencies by middleware.

Variants

Seconds

Use seconds.

Millis

Use milliseconds.

Micros

Use microseconds.

Nanos

Use nanoseconds.

Implementations

impl Clone for LatencyUnit

fn clone(self: &Self) -> LatencyUnit

impl Copy for LatencyUnit

impl Debug for LatencyUnit

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for LatencyUnit

impl RefUnwindSafe for LatencyUnit

impl Send for LatencyUnit

impl Sync for LatencyUnit

impl Unpin for LatencyUnit

impl UnsafeUnpin for LatencyUnit

impl UnwindSafe for LatencyUnit

impl<T> Any for LatencyUnit

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for LatencyUnit

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for LatencyUnit

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for LatencyUnit

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for LatencyUnit

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for LatencyUnit

impl<T> PolicyExt for LatencyUnit

fn and<P, B, E>(self: Self, other: P) -> And<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>
fn or<P, B, E>(self: Self, other: P) -> Or<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>

impl<T> ToOwned for LatencyUnit

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for LatencyUnit

impl<T, U> Into for LatencyUnit

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for LatencyUnit

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for LatencyUnit

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>