Struct FollowRedirect

struct FollowRedirect<S, P = self::policy::Standard> { ... }

Middleware that retries requests with a Service to follow redirection responses.

See the module docs for more details.

Implementations

impl<S> FollowRedirect<S>

fn new(inner: S) -> Self

Create a new FollowRedirect with a Standard redirection policy.

fn layer() -> FollowRedirectLayer

Returns a new Layer that wraps services with a FollowRedirect middleware.

impl<S, P> FollowRedirect<S, P>

fn with_policy(inner: S, policy: P) -> Self

Create a new FollowRedirect with the given redirection Policy.

fn layer_with_policy(policy: P) -> FollowRedirectLayer<P>

Returns a new Layer that wraps services with a FollowRedirect middleware with the given redirection Policy.

fn get_ref(self: &Self) -> &S

Gets a reference to the underlying service.

fn get_mut(self: &mut Self) -> &mut S

Gets a mutable reference to the underlying service.

fn into_inner(self: Self) -> S

Consumes self, returning the underlying service.

impl<ReqBody, ResBody, S, P> Service for FollowRedirect<S, P>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn call(self: &mut Self, req: Request<ReqBody>) -> <Self as >::Future

impl<S, P> Freeze for FollowRedirect<S, P>

impl<S, P> RefUnwindSafe for FollowRedirect<S, P>

impl<S, P> Send for FollowRedirect<S, P>

impl<S, P> Sync for FollowRedirect<S, P>

impl<S, P> Unpin for FollowRedirect<S, P>

impl<S, P> UnsafeUnpin for FollowRedirect<S, P>

impl<S, P> UnwindSafe for FollowRedirect<S, P>

impl<S: $crate::clone::Clone, P: $crate::clone::Clone> Clone for FollowRedirect<S, P>

fn clone(self: &Self) -> FollowRedirect<S, P>

impl<S: $crate::fmt::Debug, P: $crate::fmt::Debug> Debug for FollowRedirect<S, P>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S: $crate::marker::Copy, P: $crate::marker::Copy> Copy for FollowRedirect<S, P>

impl<T> Any for FollowRedirect<S, P>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FollowRedirect<S, P>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FollowRedirect<S, P>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FollowRedirect<S, P>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FollowRedirect<S, P>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for FollowRedirect<S, P>

impl<T> PolicyExt for FollowRedirect<S, P>

fn and<P, B, E>(self: Self, other: P) -> And<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>
fn or<P, B, E>(self: Self, other: P) -> Or<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>

impl<T> ToOwned for FollowRedirect<S, P>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for FollowRedirect<S, P>

impl<T, Request> ServiceExt for FollowRedirect<S, P>

impl<T, U> Into for FollowRedirect<S, P>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FollowRedirect<S, P>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FollowRedirect<S, P>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>