OnEarlyDropGuard

Struct OnEarlyDropGuard 

pub struct OnEarlyDropGuard<Callback: OnDropCallback> { /* private fields */ }
Available on crate feature on-early-drop only.
Runs a callback on drop unless completed is called first.

Examples

use tower_http::on_early_drop::OnEarlyDropGuard;
use std::sync::atomic::{AtomicUsize, Ordering};
use std::sync::Arc;

let count = Arc::new(AtomicUsize::new(0));
let count_for_guard = count.clone();
{
    let _guard = OnEarlyDropGuard::new(move || {
        count_for_guard.fetch_add(1, Ordering::Relaxed);
    });
}
assert_eq!(count.load(Ordering::Relaxed), 1);

Marking the guard completed suppresses the callback:

use tower_http::on_early_drop::OnEarlyDropGuard;
use std::sync::atomic::{AtomicUsize, Ordering};
use std::sync::Arc;

let count = Arc::new(AtomicUsize::new(0));
let count_for_guard = count.clone();
{
    let mut guard = OnEarlyDropGuard::new(move || {
        count_for_guard.fetch_add(1, Ordering::Relaxed);
    });
    guard.completed();
}
assert_eq!(count.load(Ordering::Relaxed), 0);

Implementations

Source

impl<Callback: OnDropCallback> OnEarlyDropGuard<Callback>

pub fn new(callback: Callback) -> Self

Create a guard that will fire callback on drop.

pub fn completed(&mut self)

Mark the guard completed and drop the callback without firing it.

Any resources captured by the callback are released immediately rather than at guard drop time.