Struct tower_http::propagate_header::PropagateHeader
source · [−]pub struct PropagateHeader<S> { /* private fields */ }propagate-header only.Expand description
Middleware that propagates headers from requests to responses.
If the header is present on the request it’ll be applied to the response as well. This could
for example be used to propagate headers such as X-Request-Id.
See the module docs for more details.
Implementations
Create a new PropagateHeader that propagates the given header.
Consumes self, returning the underlying service.
Returns a new Layer that wraps services with a PropagateHeader middleware.