Struct tower_http::request_id::SetRequestId
source · [−]pub struct SetRequestId<S, M> { /* private fields */ }request-id only.Expand description
Set request id headers and extensions on requests.
See the module docs for an example.
If MakeRequestId::make_request_id returns Some(_) and the request doesn’t already have a
header with the same name, then the header will be inserted.
Additionally RequestId will be inserted into Request::extensions so other
services can access it.
Implementations
pub fn new(inner: S, header_name: HeaderName, make_request_id: M) -> Self where
M: MakeRequestId,
pub fn new(inner: S, header_name: HeaderName, make_request_id: M) -> Self where
M: MakeRequestId,
Create a new SetRequestId.
Create a new SetRequestId that uses x-request-id as the header name.
Consumes self, returning the underlying service.
pub fn layer(
header_name: HeaderName,
make_request_id: M
) -> SetRequestIdLayer<M> where
M: MakeRequestId,
pub fn layer(
header_name: HeaderName,
make_request_id: M
) -> SetRequestIdLayer<M> where
M: MakeRequestId,
Returns a new Layer that wraps services with a SetRequestId middleware.