pub struct ServeFile(_);fs only.Expand description
Service that serves a file.
Implementations
Create a new ServeFile.
The Content-Type will be guessed from the file extension.
Create a new ServeFile with a specific mime type.
Panics
Will panic if the mime type isn’t a valid header value.
Informs the service that it should also look for a precompressed gzip version of the file.
If the client has an Accept-Encoding header that allows the gzip encoding,
the file foo.txt.gz will be served instead of foo.txt.
If the precompressed file is not available, or the client doesn’t support it,
the uncompressed version will be served instead.
Both the precompressed version and the uncompressed version are expected
to be present in the same directory. Different precompressed
variants can be combined.
Informs the service that it should also look for a precompressed brotli version of the file.
If the client has an Accept-Encoding header that allows the brotli encoding,
the file foo.txt.br will be served instead of foo.txt.
If the precompressed file is not available, or the client doesn’t support it,
the uncompressed version will be served instead.
Both the precompressed version and the uncompressed version are expected
to be present in the same directory. Different precompressed
variants can be combined.
Informs the service that it should also look for a precompressed deflate version of the file.
If the client has an Accept-Encoding header that allows the deflate encoding,
the file foo.txt.zz will be served instead of foo.txt.
If the precompressed file is not available, or the client doesn’t support it,
the uncompressed version will be served instead.
Both the precompressed version and the uncompressed version are expected
to be present in the same directory. Different precompressed
variants can be combined.
Set a specific read buffer chunk size.
The default capacity is 64kb.