Struct tower_http::set_header::request::SetRequestHeaderLayer
source · [−]pub struct SetRequestHeaderLayer<M, T> { /* private fields */ }set-header only.Expand description
Layer that applies SetRequestHeader which adds a request header.
See SetRequestHeader for more details.
Implementations
Create a new SetRequestHeaderLayer.
If a previous value exists for the same header, it is removed and replaced with the new header value.
Create a new SetRequestHeaderLayer.
The new header is always added, preserving any existing values. If previous values exist, the header will have multiple values.
Create a new SetRequestHeaderLayer.
If a previous value exists for the header, the new value is not inserted.