Struct tower_http::set_header::response::SetResponseHeaderLayer
source · [−]pub struct SetResponseHeaderLayer<M> { /* private fields */ }set-header only.Expand description
Layer that applies SetResponseHeader which adds a response header.
See SetResponseHeader for more details.
Implementations
Create a new SetResponseHeaderLayer.
If a previous value exists for the same header, it is removed and replaced with the new header value.
Create a new SetResponseHeaderLayer.
The new header is always added, preserving any existing values. If previous values exist, the header will have multiple values.
Create a new SetResponseHeaderLayer.
If a previous value exists for the header, the new value is not inserted.