pub struct TimeoutLayer { /* private fields */ }Available on crate feature
timeout only.Expand description
Layer that applies the Timeout middleware which apply a timeout to requests.
See the module docs for an example.
Implementations
Sourceimpl TimeoutLayer
impl TimeoutLayer
Sourcepub fn new(timeout: Duration) -> Self
👎Deprecated since 0.6.7: Use TimeoutLayer::with_status_code instead
pub fn new(timeout: Duration) -> Self
Use TimeoutLayer::with_status_code instead
Creates a new TimeoutLayer.
By default, it will return a 408 Request Timeout response if the request does not complete within the specified timeout.
To customize the response status code, use the with_status_code method.
Sourcepub fn with_status_code(status_code: StatusCode, timeout: Duration) -> Self
pub fn with_status_code(status_code: StatusCode, timeout: Duration) -> Self
Creates a new TimeoutLayer with the specified status code for the timeout response.