Struct tower_http::trace::DefaultOnRequest
source · [−]pub struct DefaultOnRequest { /* private fields */ }This is supported on crate feature
trace only.Implementations
Set the Level used for tracing events.
Please note that while this will set the level for the tracing events
themselves, it might cause them to lack expected information, like
request method or path. You can address this using
DefaultMakeSpan::level.
Defaults to Level::DEBUG.