Struct tower_http::trace::DefaultOnResponse
source · [−]pub struct DefaultOnResponse { /* private fields */ }trace only.Expand description
The default OnResponse implementation used by Trace.
Implementations
Set the Level used for tracing events.
Please note that while this will set the level for the tracing events
themselves, it might cause them to lack expected information, like
request method or path. You can address this using
DefaultMakeSpan::level.
Defaults to Level::DEBUG.
Set the LatencyUnit latencies will be reported in.
Defaults to LatencyUnit::Millis.
Include response headers on the Event.
By default headers are not included.