RequiredHeaderValue

Struct RequiredHeaderValue 

pub struct RequiredHeaderValue<ResBody> { /* private fields */ }
Type that rejects requests if a header is not present or does not have an expected value.