Struct tower_http::auth::require_authorization::RequireAuthorizationLayer [−][src]
pub struct RequireAuthorizationLayer<T> { /* fields omitted */ }auth only.Expand description
Layer that applies RequireAuthorization which authorizes all requests using the
Authorization header.
See the module docs for an example.
Implementations
impl<ResBody> RequireAuthorizationLayer<Bearer<ResBody>>[src]
impl<ResBody> RequireAuthorizationLayer<Bearer<ResBody>>[src]impl<ResBody> RequireAuthorizationLayer<Basic<ResBody>>[src]
impl<ResBody> RequireAuthorizationLayer<Basic<ResBody>>[src]pub fn basic(username: &str, password: &str) -> Self where
ResBody: Body + Default, [src]
pub fn basic(username: &str, password: &str) -> Self where
ResBody: Body + Default, [src]Authorize requests using a username and password pair.
The Authorization header is required to be Basic {credentials} where credentials is
base64_encode("{username}:{password}").
Since the username and password is sent in clear text it is recommended to use HTTPS/TLS with this method. However use of HTTPS/TLS is not enforced by this middleware.
impl<T> RequireAuthorizationLayer<T> where
T: AuthorizeRequest, [src]
impl<T> RequireAuthorizationLayer<T> where
T: AuthorizeRequest, [src]pub fn custom(auth: T) -> RequireAuthorizationLayer<T>[src]
pub fn custom(auth: T) -> RequireAuthorizationLayer<T>[src]Authorize requests using a custom scheme.