Enum GrpcCode

enum GrpcCode

gRPC status codes.

These variants match the gRPC status codes.

Variants

Ok

The operation completed successfully.

Cancelled

The operation was cancelled.

Unknown

Unknown error.

InvalidArgument

Client specified an invalid argument.

DeadlineExceeded

Deadline expired before operation could complete.

NotFound

Some requested entity was not found.

AlreadyExists

Some entity that we attempted to create already exists.

PermissionDenied

The caller does not have permission to execute the specified operation.

ResourceExhausted

Some resource has been exhausted.

FailedPrecondition

The system is not in a state required for the operation's execution.

Aborted

The operation was aborted.

OutOfRange

Operation was attempted past the valid range.

Unimplemented

Operation is not implemented or not supported.

Internal

Internal error.

Unavailable

The service is currently unavailable.

DataLoss

Unrecoverable data loss or corruption.

Unauthenticated

The request does not have valid authentication credentials

Implementations

impl Clone for GrpcCode

fn clone(self: &Self) -> GrpcCode

impl Copy for GrpcCode

impl Debug for GrpcCode

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for GrpcCode

impl RefUnwindSafe for GrpcCode

impl Send for GrpcCode

impl Sync for GrpcCode

impl Unpin for GrpcCode

impl UnsafeUnpin for GrpcCode

impl UnwindSafe for GrpcCode

impl<T> Any for GrpcCode

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for GrpcCode

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for GrpcCode

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for GrpcCode

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for GrpcCode

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for GrpcCode

impl<T> PolicyExt for GrpcCode

fn and<P, B, E>(self: Self, other: P) -> And<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>
fn or<P, B, E>(self: Self, other: P) -> Or<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>

impl<T> ToOwned for GrpcCode

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for GrpcCode

impl<T, U> Into for GrpcCode

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for GrpcCode

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for GrpcCode

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>