#[non_exhaustive]pub enum GrpcFailureClass {
Status(GrpcStatus),
Error(String),
}Expand description
The failure class for GrpcErrorsAsFailures.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Status(GrpcStatus)
A gRPC response was classified as a failure with the corresponding status.
Error(String)
A gRPC response was classified as an error with the corresponding error description.