Struct tower_http::classify::ServerErrorsAsFailures [−][src]
pub struct ServerErrorsAsFailures { /* fields omitted */ }Expand description
The default classifier used for normal HTTP responses.
Responses with a 5xx status code are considered failures, all others are considered
successes.
Implementations
impl ServerErrorsAsFailures[src]
impl ServerErrorsAsFailures[src]pub fn new() -> Self[src]
pub fn new() -> Self[src]Create a new ServerErrorsAsFailures.
pub fn make_classifier() -> SharedClassifier<Self>[src]
pub fn make_classifier() -> SharedClassifier<Self>[src]Returns a MakeClassifier that produces ServerErrorsAsFailures.
This is a convenience function that simply calls SharedClassifier::new.