Struct tower_http::compression::predicate::SizeAbove
source · [−]pub struct SizeAbove(_);This is supported on crate features
compression-br or compression-deflate or compression-gzip only.Expand description
Predicate that will only allow compression of responses above a certain size.
Implementations
Create a new SizeAbove predicate that will only compress responses larger than
min_size_bytes.
The response will be compressed if the exact size cannot be determined through either the
content-length header or Body::size_hint.