Struct tower_http::compression::Compression
source · [−]pub struct Compression<S, P = DefaultPredicate> { /* private fields */ }compression-br or compression-deflate or compression-gzip only.Expand description
Compress response bodies of the underlying service.
This uses the Accept-Encoding header to pick an appropriate encoding and adds the
Content-Encoding header to responses.
See the module docs for more details.
Implementations
Creates a new Compression wrapping the service.
Consumes self, returning the underlying service.
Returns a new Layer that wraps services with a Compression middleware.
This is supported on crate feature compression-gzip only.
compression-gzip only.Sets whether to enable the gzip encoding.
This is supported on crate feature compression-deflate only.
compression-deflate only.Sets whether to enable the Deflate encoding.
This is supported on crate feature compression-br only.
compression-br only.Sets whether to enable the Brotli encoding.
Disables the gzip encoding.
This method is available even if the gzip crate feature is disabled.
Disables the Deflate encoding.
This method is available even if the deflate crate feature is disabled.
Disables the Brotli encoding.
This method is available even if the br crate feature is disabled.
Replace the current compression predicate.
Predicates are used to determine whether a response should be compressed or not.
The default predicate is DefaultPredicate. See its documentation for more
details on which responses it wont compress.
Changing the compression predicate
use tower_http::compression::{
Compression,
predicate::{Predicate, NotForContentType, DefaultPredicate},
};
use tower::util::service_fn;
// Placeholder service_fn
let service = service_fn(|_: ()| async {
Ok::<_, std::io::Error>(http::Response::new(()))
});
// build our custom compression predicate
// its recommended to still include `DefaultPredicate` as part of
// custom predicates
let predicate = DefaultPredicate::new()
// don't compress responses who's `content-type` starts with `application/json`
.and(NotForContentType::new("application/json"));
let service = Compression::new(service).compress_when(predicate);See predicate for more utilities for building compression predicates.
Responses that are already compressed (ie have a content-encoding header) will never be
recompressed, regardless what they predicate says.