Struct And
struct And<A, B> { ... }
A redirection Policy that combines the results of two Policys.
See [PolicyExt::and][super::PolicyExt::and] for more details.
Implementations
impl<A, B> Freeze for And<A, B>
impl<A, B> RefUnwindSafe for And<A, B>
impl<A, B> Send for And<A, B>
impl<A, B> Sync for And<A, B>
impl<A, B> Unpin for And<A, B>
impl<A, B> UnsafeUnpin for And<A, B>
impl<A, B> UnwindSafe for And<A, B>
impl<A: $crate::clone::Clone, B: $crate::clone::Clone> Clone for And<A, B>
fn clone(self: &Self) -> And<A, B>
impl<A: $crate::default::Default, B: $crate::default::Default> Default for And<A, B>
fn default() -> And<A, B>
impl<A: $crate::fmt::Debug, B: $crate::fmt::Debug> Debug for And<A, B>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<A: $crate::marker::Copy, B: $crate::marker::Copy> Copy for And<A, B>
impl<Bd, E, A, B> Policy for And<A, B>
fn redirect(self: &mut Self, attempt: &Attempt<'_>) -> Result<Action, E>fn on_request(self: &mut Self, request: &mut Request<Bd>)fn clone_body(self: &Self, body: &Bd) -> Option<Bd>
impl<T> Any for And<A, B>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for And<A, B>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for And<A, B>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for And<A, B>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for And<A, B>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for And<A, B>
impl<T> PolicyExt for And<A, B>
fn and<P, B, E>(self: Self, other: P) -> And<T, P> where T: Policy<B, E>, P: Policy<B, E>fn or<P, B, E>(self: Self, other: P) -> Or<T, P> where T: Policy<B, E>, P: Policy<B, E>
impl<T> ToOwned for And<A, B>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> WithSubscriber for And<A, B>
impl<T, U> Into for And<A, B>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for And<A, B>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for And<A, B>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>