Struct Limited
struct Limited { ... }
A redirection Policy that limits the number of successive redirections.
Implementations
impl Limited
fn new(max: usize) -> SelfCreate a new
Limitedwith a limit ofmaxredirections.
impl Clone for Limited
fn clone(self: &Self) -> Limited
impl Copy for Limited
impl Debug for Limited
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Default for Limited
fn default() -> SelfReturns the default
Limitedwith a limit of20redirections.
impl Freeze for Limited
impl RefUnwindSafe for Limited
impl Send for Limited
impl Sync for Limited
impl Unpin for Limited
impl UnsafeUnpin for Limited
impl UnwindSafe for Limited
impl<B, E> Policy for Limited
fn redirect(self: &mut Self, _: &Attempt<'_>) -> Result<Action, E>
impl<T> Any for Limited
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Limited
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Limited
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Limited
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Limited
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for Limited
impl<T> PolicyExt for Limited
fn and<P, B, E>(self: Self, other: P) -> And<T, P> where T: Policy<B, E>, P: Policy<B, E>fn or<P, B, E>(self: Self, other: P) -> Or<T, P> where T: Policy<B, E>, P: Policy<B, E>
impl<T> ToOwned for Limited
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> WithSubscriber for Limited
impl<T, U> Into for Limited
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Limited
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Limited
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>