Struct FollowRedirectLayer

struct FollowRedirectLayer<P = self::policy::Standard> { ... }

Layer for retrying requests with a Service to follow redirection responses.

See the module docs for more details.

Implementations

impl FollowRedirectLayer

fn new() -> Self

Create a new FollowRedirectLayer with a Standard redirection policy.

impl<P> FollowRedirectLayer<P>

fn with_policy(policy: P) -> Self

Create a new FollowRedirectLayer with the given redirection Policy.

impl<P> Freeze for FollowRedirectLayer<P>

impl<P> RefUnwindSafe for FollowRedirectLayer<P>

impl<P> Send for FollowRedirectLayer<P>

impl<P> Sync for FollowRedirectLayer<P>

impl<P> Unpin for FollowRedirectLayer<P>

impl<P> UnsafeUnpin for FollowRedirectLayer<P>

impl<P> UnwindSafe for FollowRedirectLayer<P>

impl<P: $crate::clone::Clone> Clone for FollowRedirectLayer<P>

fn clone(self: &Self) -> FollowRedirectLayer<P>

impl<P: $crate::default::Default> Default for FollowRedirectLayer<P>

fn default() -> FollowRedirectLayer<P>

impl<P: $crate::fmt::Debug> Debug for FollowRedirectLayer<P>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<P: $crate::marker::Copy> Copy for FollowRedirectLayer<P>

impl<S, P> Layer for FollowRedirectLayer<P>

fn layer(self: &Self, inner: S) -> <Self as >::Service

impl<T> Any for FollowRedirectLayer<P>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FollowRedirectLayer<P>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FollowRedirectLayer<P>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FollowRedirectLayer<P>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FollowRedirectLayer<P>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for FollowRedirectLayer<P>

impl<T> PolicyExt for FollowRedirectLayer<P>

fn and<P, B, E>(self: Self, other: P) -> And<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>
fn or<P, B, E>(self: Self, other: P) -> Or<T, P>
where
    T: Policy<B, E>,
    P: Policy<B, E>

impl<T> ToOwned for FollowRedirectLayer<P>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for FollowRedirectLayer<P>

impl<T, U> Into for FollowRedirectLayer<P>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FollowRedirectLayer<P>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FollowRedirectLayer<P>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>