Struct tower_http::metrics::in_flight_requests::InFlightRequestsCounter [−][src]
pub struct InFlightRequestsCounter { /* fields omitted */ }metrics only.Expand description
An atomic counter that keeps track of the number of in-flight requests.
This will normally combined with InFlightRequestsLayer or InFlightRequests which will
update the counter as requests arrive.
Implementations
impl InFlightRequestsCounter[src]
impl InFlightRequestsCounter[src]pub async fn run_emitter<F, Fut>(self, interval: Duration, emit: F) where
F: FnMut(usize) -> Fut + Send + 'static,
Fut: Future<Output = ()> + Send, [src]
pub async fn run_emitter<F, Fut>(self, interval: Duration, emit: F) where
F: FnMut(usize) -> Fut + Send + 'static,
Fut: Future<Output = ()> + Send, [src]Run a future every interval which receives the current number of in-flight requests.
This can be used to send the current count to your metrics system.
This function will loop forever so normally it is called with tokio::spawn:
use tower_http::metrics::in_flight_requests::InFlightRequestsCounter; use std::time::Duration; let counter = InFlightRequestsCounter::new(); tokio::spawn( counter.run_emitter(Duration::from_secs(10), |count: usize| async move { // Send `count` to metrics system. }), );