Struct tower_http::propagate_header::PropagateHeader [−][src]
pub struct PropagateHeader<S> { /* fields omitted */ }propagate-header only.Expand description
Middleware that propagates headers from requests to responses.
If the header is present on the request it’ll be applied to the response as well. This could
for example be used to propagate headers such as X-Request-Id.
See the module docs for more details.
Implementations
impl<S> PropagateHeader<S>[src]
impl<S> PropagateHeader<S>[src]pub fn new(inner: S, header: HeaderName) -> Self[src]
pub fn new(inner: S, header: HeaderName) -> Self[src]Create a new PropagateHeader that propagates the given header.
pub fn into_inner(self) -> S[src]
pub fn into_inner(self) -> S[src]Consumes self, returning the underlying service.
pub fn layer(header: HeaderName) -> PropagateHeaderLayer[src]
pub fn layer(header: HeaderName) -> PropagateHeaderLayer[src]Returns a new Layer that wraps services with a PropagateHeader middleware.