Struct tower_http::propagate_header::PropagateHeaderLayer [−][src]
pub struct PropagateHeaderLayer { /* fields omitted */ }This is supported on crate feature
propagate-header only.Expand description
Layer that applies PropagateHeader which propagates headers from requests to responses.
If the header is present on the request it’ll be applied to the response as well. This could
for example be used to propagate headers such as X-Request-Id.
See the module docs for more details.
Implementations
impl PropagateHeaderLayer[src]
impl PropagateHeaderLayer[src]pub fn new(header: HeaderName) -> Self[src]
pub fn new(header: HeaderName) -> Self[src]Create a new PropagateHeaderLayer.